MCPcopy Create free account
hub / github.com/AdaptiveCpp/AdaptiveCpp / copy_kernel

Function copy_kernel

tests/compiler/pcuda/kernel_launch.cpp:16–20  ·  view source on GitHub ↗

Source from the content-addressed store, hash-verified

14
15template<class T>
16__global__ void copy_kernel(T* in, T* out) {
17 int gid = threadIdx.x + blockIdx.x * blockDim.x;
18
19 out[gid] = in[gid];
20}
21
22template<class T>
23__global__ void wrapper(T* in, T* out) {

Callers 1

wrapperFunction · 0.85

Calls

no outgoing calls

Tested by

no test coverage detected